@@ -7,7 +7,7 @@ from pathlib import Path
 from typing import Union
 
 import click
-import stubber.utils as utils
+from stubber.utils import generate_pyi_files
 from stubber.utils.post import do_post_processing
 
 from .cli import stubber_cli
@@ -23,6 +23,6 @@ def cli_stub(source: Union[str, Path]):
     "Create or update .pyi type hint files."
 
     log.info("Generate type hint files (pyi) in folder: {}".format(source))
-    OK = utils.generate_pyi_files(Path(source))
+    OK = generate_pyi_files(Path(source))
     do_post_processing([Path(source)], pyi=True, black=True)
     return 0 if OK else 1
